@@ -5,12 +5,12 @@ built_modules = list(name for name in
 shiboken_library_soversion = str(5.15)
 pyside_library_soversion = str(5.15)
 
-version = "5.15.0a1"
-version_info = (5, 15, 0, "a", "1")
+version = "5.15.2.1"
+version_info = (5, 15, 2.1, "", "")
 
-__build_date__ = '2022-04-04T19:12:35+00:00'
+__build_date__ = '2022-09-09T08:34:41+00:00'
 
-__build_commit_hash__ = 'edf28c5e97800b0c3442cd5351b6811ec85beead'
-__build_commit_hash_described__ = 'v5.11.2-1169-gedf28c5'
+__build_commit_hash__ = '9282e03de471bb3772c8d3997159e49c113d7678'
+__build_commit_hash_described__ = 'v5.15.2.1'
 
-__setup_py_package_version__ = '5.15.0a1'
+__setup_py_package_version__ = '5.15.2.1'
